===========================================================
Masakari Customized Recovery Workflow Configuration Options
===========================================================
masakari-custom-recovery-methods.conf.sample
The following is a sample Masakari recovery workflow configuration for
adaptation and use.

The sample configuration can also be downloaded from :download:`here
</_static/masakari-custom-recovery-methods.conf.sample>`.

.. literalinclude:: /_static/masakari-custom-recovery-methods.conf.sample
